package com.muyu.product.cache;

import com.muyu.common.cache.abs.AtomicSequenceCacheAbs;
import com.muyu.common.core.text.Convert;
import com.muyu.product.cache.datasource.ProjectSkuStockData;
import com.muyu.product.cache.key.SkuStockKey;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 商品SKU库存缓存
 *
 * @author CHX
 * on 2024/4/2 0002
 */
@Service
public class ProjectSkuStockCache extends AtomicSequenceCacheAbs<SkuStockKey> {

    @Autowired
    private ProjectSkuStockData projectSkuStockData;

    @Override
    public String keyPre() {
        return "project:sku:stock:";
    }

    @Override
    public String encode(SkuStockKey skuStockKey) {
        return keyPre() + skuStockKey.getProjectId() + ":" + skuStockKey.getSku();
    }

    @Override
    public SkuStockKey decode(String redisKey) {
        String[] split = redisKey.replace(keyPre(), "").split(":");
        return SkuStockKey.builder()
                .projectId(Convert.toLong(split[0]))
                .sku(split[1])
                .build();
    }

    @Override
    public Long getData(SkuStockKey key) {
        return projectSkuStockData.getData(key);
    }
}
