package com.muyu.product.cache.datasource.impl;

import com.muyu.common.core.domain.Result;
import com.muyu.product.cache.datasource.ProjectSkuData;
import com.muyu.product.domain.ProjectSkuInfo;
import com.muyu.project.remote.RemoteProjectSkuService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 商品sku实现层
 *
 * @author CHX
 * on 2024/4/9 星期二
 */
@Service
public class ProjectSkuDataRemoteImpl implements ProjectSkuData {

    @Autowired
    private RemoteProjectSkuService remoteProjectSkuService;

    @Override
    public Map<String, ProjectSkuInfo> getData(Long projectId) {
        Result<List<ProjectSkuInfo>> listResult = remoteProjectSkuService.listByProjectId(projectId);
        if (Result.isError(listResult)) {
            return new HashMap<>();
        }
        List<ProjectSkuInfo> projectSkuInfoList = listResult.getData();
        return projectSkuInfoList.stream()
                .collect(Collectors.toMap(ProjectSkuInfo::getSku, projectSkuInfo -> projectSkuInfo));
    }

    @Override
    public ProjectSkuInfo getData(Long projectId, String projectSku) {
        Result<ProjectSkuInfo> result = remoteProjectSkuService.getInfoByProjectIdAndSku(projectId, projectSku);
        if (Result.isError(result)) {
            return new ProjectSkuInfo();
        }
        return result.getData();
    }
}
