package com.muyu.project.remote;

import com.muyu.common.core.constant.ServiceNameConstants;
import com.muyu.common.core.domain.Result;
import com.muyu.product.domain.ProjectSkuInfo;
import com.muyu.project.remote.factory.RemoteProjectSkuFactory;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;

import java.util.List;

/**
 * 远程调用业务层
 *
 * @author CHX
 * on 2024/4/7 星期日
 */
@FeignClient(
        contextId = "remoteProjectSkuService",
        value = ServiceNameConstants.PRODUCT_SERVICE,
        fallbackFactory = RemoteProjectSkuFactory.class,
        path = "/sku"
)
public interface RemoteProjectSkuService {
    @GetMapping("/info/{projectId}/{projectSku}")
    public Result<ProjectSkuInfo> getInfoByProjectIdAndSku
            (@PathVariable("projectId") Long projectId,@PathVariable("projectSku") String projectSku);

    /**
     * 通过商品ID获取sku集合
     * @param projectId 商品ID
     * @return 商品sku信息
     */
    @GetMapping("/list/{projectId}")
    public Result<List<ProjectSkuInfo>> listByProjectId(@PathVariable("projectId") Long projectId);
}
