package com.muyu.shop.cart.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.muyu.shop.cart.domain.CartInfo;
import com.muyu.shop.cart.domain.req.CartInfoEditNumReq;
import com.muyu.shop.cart.domain.req.CartInfoIsSelectedUpdReq;
import com.muyu.shop.cart.domain.req.RemoveCartProjectReq;
import com.muyu.shop.cart.domain.resp.CartDetailResp;

import java.util.List;

/**
 * 购物车Service接口
 *
 * @author DongZeLiang
 * @date 2024-03-29
 */
public interface CartInfoService extends IService<CartInfo> {
    /**
     * 查询购物车列表
     *
     * @param cartInfo 购物车
     * @return 购物车集合
     */
    public List<CartInfo> list(CartInfo cartInfo);

    /**
     * 新增购物车
     * @param cartInfo 购物车信息
     * @return 是否添加成功
     */
    boolean add(CartInfo cartInfo);

    /**
     * 获取购物车详情
     * @return 购物车详情
     */
    CartDetailResp detail();

    /**
     * 修改状态
     * @param cartInfoIsSelectedUpdReqList
     */
    void cartInfoIsSelected(List<CartInfoIsSelectedUpdReq> cartInfoIsSelectedUpdReqList);

    /**
     * 修改购物车内商品数量
     * @param cartInfoEditNumReq
     */
    void cartInfoEditNum(CartInfoEditNumReq cartInfoEditNumReq);

    /**
     * 删除购物车
     * @param removeCartProjectReqList
     */
    void removeByRemoveCartProjectList(List<RemoveCartProjectReq> removeCartProjectReqList);
}
