package com.muyu.shop.cart.service.sourcedata;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.muyu.shop.cart.cache.key.CartHashKey;
import com.muyu.shop.cart.cache.sourcedata.CartData;
import com.muyu.shop.cart.domain.CartInfo;
import com.muyu.shop.cart.service.CartInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 缓存实现
 *
 * @author CHX
 * on 2024/4/2 0002
 */
@Service
public class CartDataImpl implements CartData {

    @Autowired
    private CartInfoService cartInfoService;

    @Override
    public Map<CartHashKey, CartInfo> getData(Long key) {
        List<CartInfo> cartInfoList = cartInfoService.list(new LambdaQueryWrapper<>() {{
            eq(CartInfo::getUserId, key);
        }});
        return cartInfoList.stream()
                .collect(Collectors.toMap(cartInfo -> CartHashKey.builder()
                        .projectId(cartInfo.getProjectId())
                        .projectSku(cartInfo.getProjectSku())
                        .build(), cartInfo -> cartInfo));
    }

    @Override
    public CartInfo getData(Long userId, CartHashKey hashKey) {
        return cartInfoService.getOne(new LambdaQueryWrapper<>(){{
            eq(CartInfo::getUserId,userId);
            eq(CartInfo::getProjectId,hashKey.getProjectId());
            eq(CartInfo::getProjectSku,hashKey.getProjectSku());
        }});
    }
}
