package com.forest;

import com.alibaba.nacos.shaded.com.google.common.collect.Lists;
import com.muyu.common.system.domain.SysDistrict;
import com.muyu.system.MuYuSystemApplication;
import com.muyu.system.forest.gaode.api.GaoDeBaseApi;
import com.muyu.system.forest.gaode.api.resp.District;
import com.muyu.system.forest.gaode.api.resp.DistrictResult;
import com.muyu.system.service.SysDistrictService;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;

import javax.annotation.Resource;
import java.util.List;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.TimeUnit;

/**
 * 测试
 *
 * @author CHX
 * on 2024/4/11 星期四
 */
@SpringBootTest(classes = MuYuSystemApplication.class)
public class FoRestTest {

    @Resource
    private GaoDeBaseApi gaoDeBaseApi;

    @Autowired
    private SysDistrictService sysDistrictService;

    @Test
    public void testApiGaoDe() {
        DistrictResult districtResult = gaoDeBaseApi.district("广东省", "3");
        List<District> districtList = districtResult.getDistricts();
        if (districtList.size() == 1 && "中华人民共和国".equals(districtList.get(0).getName())) {
            districtList = districtList.get(0).getDistricts();
        }

        // 使用线程池并发处理数据
        int NUM_THREADS = 10;  // 根据实际情况调整线程数量
        int SUB_LIST_SIZE = (int) Math.ceil((double) districtList.size() / NUM_THREADS);
        ExecutorService executor = Executors.newFixedThreadPool(NUM_THREADS);

        for (List<District> subList : Lists.partition(districtList, SUB_LIST_SIZE)) {
            executor.submit(() -> {
                conversion(0L, null, subList);
            });
        }

        executor.shutdown();
        try {
            executor.awaitTermination(Long.MAX_VALUE, TimeUnit.NANOSECONDS);
        } catch (InterruptedException e) {
            throw new RuntimeException(e);
        }
    }

    // 递归获取父级ID、级别编码
    public void conversion(Long parentId, String codeLevel, List<District> districtList) {
        if (districtList == null || districtList.isEmpty()) {
            return;
        }

        if (codeLevel == null || codeLevel.length() == 0) {
            codeLevel = parentId + "";
        } else {
            codeLevel = codeLevel + "-" + parentId;
        }

        for (District district : districtList) {
            SysDistrict sysDistrict = SysDistrict.builder()
                    .parentId(parentId)
                    .level(district.getLevel())
                    .code("[]".equals(district.getCode()) ? "-" : district.getCode())
                    .codeLevel(codeLevel)
                    .name(district.getName())
                    .center(district.getCenter())
                    .areaCode(district.getAreaCode())
                    .build();
            sysDistrictService.save(sysDistrict);

            conversion(sysDistrict.getId(), sysDistrict.getCodeLevel(), district.getDistricts());
        }
    }
}
